#define DEBOUNCE 200  // button debouncer (if using buttons or reed switches)
#define ARDUINO_RX 5  //should connect to TX of the Serial MP3 Player module
#define ARDUINO_TX 6  //connect to RX of the module

#include <SoftwareSerial.h>
#include <Wire.h>
#include "Adafruit_MCP23017.h"

/************ Command byte **************************/
#define CMD_NEXT_SONG     0X01  // Play next song.
#define CMD_PREV_SONG     0X02  // Play previous song.
#define CMD_PLAY_W_INDEX  0X03
#define CMD_VOLUME_UP     0X04
#define CMD_VOLUME_DOWN   0X05
#define CMD_SET_VOLUME    0X06

#define CMD_SNG_CYCL_PLAY 0X08  // Single Cycle Play.
#define CMD_SEL_DEV       0X09
#define CMD_SLEEP_MODE    0X0A
#define CMD_WAKE_UP       0X0B
#define CMD_RESET         0X0C
#define CMD_PLAY          0X0D
#define CMD_PAUSE         0X0E
#define CMD_PLAY_FOLDER_FILE 0X0F

#define CMD_STOP_PLAY     0X16
#define CMD_FOLDER_CYCLE  0X17
#define CMD_SHUFFLE_PLAY  0x18 //
#define CMD_SET_SNGL_CYCL 0X19 // Set single cycle.

#define CMD_SET_DAC 0X1A
#define DAC_ON  0X00
#define DAC_OFF 0X01

#define CMD_PLAY_W_VOL        0X22
#define CMD_PLAYING_N         0x4C
#define CMD_QUERY_STATUS      0x42
#define CMD_QUERY_VOLUME      0x43
#define CMD_QUERY_FLDR_TRACKS 0x4e
#define CMD_QUERY_TOT_TRACKS  0x48
#define CMD_QUERY_FLDR_COUNT  0x4f

#define SINGLE_CYCLE_OFF  0X01

/*********************************************************************/


/////////////////////////////////
//// GLOBAL VARIABLES (BELOW) //
///////////////////////////////

// variables for Serial MP3 player
static int8_t Send_buf[8] = {0}; // Buffer for Send commands.  // BETTER LOCALLY
static uint8_t ansbuf[10] = {0}; // Buffer for the answers.    // BETTER LOCALLY
static int8_t pre_vol, volume = 0x0f; // Volume. 0-30 DEC values. 0x0f = 15.
String mp3Answer;           // Answer from the MP3.
boolean playing = false;    // switch Play to Pause or viceversa.

SoftwareSerial mp3(ARDUINO_RX, ARDUINO_TX);

//Variables for drawer trigger/file logic


boolean donePlaying = false; // tracks if file is done or not
boolean drawerOpen = false; // tracks if ANY drawer is open
int drawerNumber; // allows feedback on which drawer is open (for debugging)
int incomingByte; // incoming byte from mp3 player


//Variables for drawer number, file count per drawer, pin for drawer sensor
// ROW 1 (Top)
const int drawer1num = 1;
const int drawer2num = 2;
const int drawer3num = 3;
const int drawer4num = 4;
const int drawer5num = 5;
const int drawer6num = 6;
//ROW 2 (middle)
const int drawer7num = 7;
const int drawer8num = 8;
const int drawer9num = 9;
const int drawer10num = 10;
//ROW 3 (bottom)
const int drawer11num = 11;
const int drawer12num = 12;
const int drawer13num = 13;
const int drawer14num = 14;
const int drawer15num = 15;
const int drawer16num = 16;


//define number of files in each drawer here
const int drawer1size = 7;    //Portugal
const int drawer2size = 11;   //Croatia
const int drawer3size = 13;   //Germany (solo)
const int drawer4size = 7;    //Panama
const int drawer5size = 20;   //Turkey
const int drawer6size = 9;    //Greece
const int drawer7size = 17;   //Thailand
const int drawer8size = 19;   //Laos & Vietnam
const int drawer9size = 7;    //Rim to Rim: Grand Canyon
const int drawer10size = 24;  //France
const int drawer11size = 17;  //Belgium & The Netherlands
const int drawer12size = 0;
const int drawer13size = 0;
const int drawer14size = 0;
const int drawer15size = 0;
const int drawer16size = 0;

//define drawer sensor pins here
const int drawer1pin = (drawer1num - 1);
const int drawer2pin = (drawer2num - 1);
const int drawer3pin = (drawer3num - 1);
const int drawer4pin = (drawer4num - 1);
const int drawer5pin = (drawer5num - 1);
const int drawer6pin = (drawer6num - 1);
const int drawer7pin = (drawer7num - 1);
const int drawer8pin = (drawer8num - 1);
const int drawer9pin = (drawer9num - 1);
const int drawer10pin = (drawer10num - 1);
const int drawer11pin = (drawer11num - 1);
const int drawer12pin = (drawer12num - 1);
const int drawer13pin = (drawer13num - 1);
const int drawer14pin = (drawer14num - 1);
const int drawer15pin = (drawer15num - 1);
const int drawer16pin = (drawer16num - 1);
//.... etc

// create variables for array, size, drawer state here. Need one for each drawer.
int drawer1array[drawer1size];
int drawer2array[drawer2size];
int drawer3array[drawer3size];
int drawer4array[drawer4size];
int drawer5array[drawer5size];
int drawer6array[drawer6size];
int drawer7array[drawer7size];
int drawer8array[drawer8size];
int drawer9array[drawer9size];
int drawer10array[drawer10size];
int drawer11array[drawer11size];
int drawer12array[drawer12size];
int drawer13array[drawer13size];
int drawer14array[drawer14size];
int drawer15array[drawer15size];
int drawer16array[drawer16size];

int drawerState1; 
int drawerState2; 
int drawerState3;
int drawerState4; 
int drawerState5; 
int drawerState6;
int drawerState7; 
int drawerState8; 
int drawerState9;
int drawerState10; 
int drawerState11; 
int drawerState12;
int drawerState13; 
int drawerState14; 
int drawerState15;
int drawerState16;


